@@ -74,11 +74,15 @@ from .usecases.parking_space_detection import ParkingSpaceConfig
 from .usecases.underwater_pollution_detection import UnderwaterPlasticConfig
 from .usecases.pedestrian_detection import PedestrianDetectionConfig
 from .usecases.age_detection import AgeDetectionConfig
+from .usecases.mask_detection import MaskDetectionConfig
+
 
 from .usecases.weld_defect_detection import WeldDefectConfig
 
 from .usecases.car_damage_detection import CarDamageConfig
 from .usecases.price_tag_detection import PriceTagConfig
+from .usecases.banana_defect_detection import BananaMonitoringConfig
+from .usecases.distracted_driver_detection import DistractedDriverConfig
 
 # Use case implementations
 from .usecases import (
@@ -92,6 +96,7 @@ from .usecases import (
     CarDamageDetectionUseCase,
     VehicleMonitoringUseCase,
     FireSmokeUseCase,
+    MaskDetectionUseCase,
     ParkingSpaceUseCase,
     FlareAnalysisUseCase,
     PotholeSegmentationUseCase,
@@ -99,8 +104,10 @@ from .usecases import (
     UnderwaterPlasticUseCase,
     PedestrianDetectionUseCase,
     AgeDetectionUseCase,
+    BananaMonitoringUseCase,
     WeldDefectUseCase,
-    PriceTagUseCase
+    PriceTagUseCase,
+    DistractedDriverUseCase
 )
 
 # Register use cases automatically
@@ -120,10 +127,13 @@ _parking_space_detection = ParkingSpaceUseCase()
 _underwater_pollution_detection = UnderwaterPlasticUseCase()
 _pedestrian_detection = PedestrianDetectionUseCase()
 _age_detection = AgeDetectionUseCase()
+_mask_detection = MaskDetectionUseCase()
+_banana_defect_detection = BananaMonitoringUseCase()
 
 _weld_defect_detection = WeldDefectUseCase()
 _pricetag_detection = PriceTagUseCase()
 _car_damage = CarDamageDetectionUseCase()
+_distracted_driver = DistractedDriverUseCase()
 
 registry.register_use_case(_people_counting.category, _people_counting.name, PeopleCountingUseCase)
 registry.register_use_case(_customer_service.category, _customer_service.name, CustomerServiceUseCase)
@@ -143,8 +153,11 @@ registry.register_use_case(_pedestrian_detection.category, _pedestrian_detection
 registry.register_use_case(_age_detection.category, _age_detection.name, AgeDetectionUseCase)
 registry.register_use_case(_pricetag_detection.category, _pricetag_detection.name, PriceTagUseCase)
 registry.register_use_case(_weld_defect_detection.category, _weld_defect_detection.name, WeldDefectUseCase  )
+registry.register_use_case(_mask_detection.category, _mask_detection.name, MaskDetectionUseCase)
+registry.register_use_case(_banana_defect_detection.category, _banana_defect_detection.name, BananaMonitoringUseCase)
 
 registry.register_use_case(_car_damage.category, _car_damage.name, CarDamageDetectionUseCase)
+registry.register_use_case(_distracted_driver.category, _distracted_driver.name, DistractedDriverUseCase)
 
 # Utility functions - organized by category
 from .utils import (  # noqa: E402
@@ -277,6 +290,7 @@ __all__ = [
     'CustomerServiceConfig',
     'ColorDetectionConfig',
     'LicensePlateConfig',
+    'MaskDetectionConfig',
     'CarDamageConfig',
     'ParkingSpaceConfig',
     'PotholeConfig',
@@ -295,6 +309,8 @@ __all__ = [
     'AgeDetectionConfig',
     'WeldDefectConfig',
     'PriceTagConfig',
+    'BananaMonitoringConfig',
+    'DistractedDriverConfig',
 
     # Use case classes
     'PeopleCountingUseCase',
@@ -305,6 +321,7 @@ __all__ = [
     'ColorDetectionUseCase',
     'PPEComplianceUseCase',
     'PotholeSegmentationUseCase',
+    'MaskDetectionUseCase',
     'VehicleMonitoringUseCase',
     'FireSmokeUseCase',
     'CarDamageDetectionUseCase',
@@ -315,7 +332,9 @@ __all__ = [
     'PedestrianDetectionUseCase',
     'AgeDetectionUseCase',
     'WeldDefectUseCase',
+    'BananaMonitoringUseCase',
     'PriceTagUseCase',
+    'DistractedDriverUseCase',
     
     # Base classes for extension
     'BaseProcessor',
