@@ -403,6 +403,7 @@ class ConfigManager:
             "parking_space_detection": None,
             "car_damage_detection":None,
             "weld_defect_detection" : None,
+            "banana_defect_detection" : None,
         }
 
     def register_config_class(self, usecase: str, config_class: type) -> None:
@@ -424,6 +425,14 @@ class ConfigManager:
             return VehicleMonitoringConfig
         except ImportError:
             return None
+        
+    def banana_defect_detection_config_class(self):
+        """Get Banana monitoring class to avoid circular imports."""
+        try:
+            from ..usecases.banana_defect_detection import BananaMonitoringConfig
+            return BananaMonitoringConfig
+        except ImportError:
+            return None
 
     def _get_fire_smoke_detection_config_class(self):
         """Register a configuration class for a use case."""
@@ -520,6 +529,14 @@ class ConfigManager:
             return PriceTagConfig
         except ImportError:
             return None
+    
+    def distracted_driver_detection_config_class(self):
+        """Register a configuration class for a use case."""
+        try:
+            from ..usecases.distracted_driver_detection import DistractedDriverConfig
+            return DistractedDriverConfig
+        except ImportError:
+            return None
 
     def create_config(self, usecase: str, category: Optional[str] = None, **kwargs) -> BaseConfig:
         """
@@ -720,6 +737,22 @@ class ConfigManager:
                 **kwargs
             )
 
+        elif usecase == "fruit_monitoring":
+            # Import here to avoid circular import
+            from ..usecases.banana_defect_detection import BananaMonitoringConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = BananaMonitoringConfig(
+                category=category or "agriculture",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
+
         elif usecase == "vehicle_monitoring":
             # Import here to avoid circular import
             from ..usecases.vehicle_monitoring import VehicleMonitoringConfig
@@ -880,6 +913,21 @@ class ConfigManager:
                 alert_config=alert_config,
                 **kwargs
             )
+        elif usecase == "distracted_driver_detection":
+            # Import here to avoid circular import
+            from ..usecases.distracted_driver_detection import DistractedDriverConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = DistractedDriverConfig(
+                category=category or "automobile",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
             
         else:
             raise ConfigValidationError(f"Unknown use case: {usecase}")
@@ -1015,6 +1063,13 @@ class ConfigManager:
             from ..usecases.vehicle_monitoring import VehicleMonitoringConfig
             default_config = VehicleMonitoringConfig()
             return default_config.to_dict()
+        
+        elif usecase == "fruit_monitoring":
+            # Import here to avoid circular import
+            from ..usecases.banana_defect_detection import BananaMonitoringConfig
+            default_config = BananaMonitoringConfig()
+            return default_config.to_dict()
+        
         elif usecase == "weld_defect_detection":
             # Import here to avoid circular import
             from ..usecases.weld_defect_detection import WeldDefectConfig
@@ -1063,6 +1118,11 @@ class ConfigManager:
             from ..usecases.price_tag_detection import PriceTagConfig
             default_config = PriceTagConfig()
             return default_config.to_dict()
+        elif usecase == "distracted_driver_detection":
+            # Import here to avoid circular import
+            from ..usecases.distracted_driver_detection import DistractedDriverConfig
+            default_config = DistractedDriverConfig()
+            return default_config.to_dict()
         elif usecase not in self._config_classes:
             raise ConfigValidationError(f"Unsupported use case: {usecase}")
 
