@@ -435,8 +435,14 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
             #             break
 
             # Compose result data with flattened agg_summary
-            result_data = dict(analytics_results)
-            result_data["agg_summary"] = agg_summary
+            if not isinstance(analytics_results, dict):
+                result_data = dict(analytics_results)
+            else:
+                result_data = analytics_results
+            
+            result_data["events"]= agg_summary["events"]
+            result_data["tracking_stats"]= agg_summary["tracking_stats"]
+            #result_data["agg_summary"] = agg_summary
 
 
             # # Ensure raw_output is always a list, including inside model_output
